/*
 *  neoCMM.h
 *  
 *
 *  Created by Carles on 24/05/08.
 *  Copyright 2008 Indit Software. All rights reserved.
 *
 */

#pragma once

#ifndef _NEO_CMM_H_
#define _NEO_CMM_H_

#ifdef _MSC_VER
	#ifdef NEOCMM_EXPORTS
		#define NEOCMM_API_DEC __declspec(dllexport)
	#else
		#define NEOCMM_API_DEC __declspec(dllimport)
	#endif
#else
	#define NEOCMM_API_DEC __attribute__((visibility("default")))
#endif

#include "neoCMMDef.h"

#ifndef NULL
#define NULL 0
#endif


#define NEOCMM_F_ENUM_RECURSIVE		0x00000001
#define NEOCMM_F_ENUM_KEEPHANDLES	0x00000002

#define NEOCMM_F_ENUM_CS_ANY		0x0000FF00
#define NEOCMM_F_ENUM_CS_RGB		0x00000100
#define NEOCMM_F_ENUM_CS_GRAY		0x00000200
#define NEOCMM_F_ENUM_CS_LAB		0x00000400
#define NEOCMM_F_ENUM_CS_CMYK		0x00000800
#define NEOCMM_F_ENUM_CS_NCHA5	0x00001000
#define NEOCMM_F_ENUM_CS_NCHA6	0x00002000
#define NEOCMM_F_ENUM_CS_NCHA7	0x00004000
#define NEOCMM_F_ENUM_CS_NCHA8	0x00008000

#define NEOCMM_F_ENUM_TYPE_ANY				0x00FF0000
#define NEOCMM_F_ENUM_TYPE_INPUT			0x00010000
#define NEOCMM_F_ENUM_TYPE_DISPLAY		0x00020000
#define NEOCMM_F_ENUM_TYPE_OUTPUT			0x00040000
#define NEOCMM_F_ENUM_TYPE_LINK				0x00080000
#define NEOCMM_F_ENUM_TYPE_ABSTRACT		0x00100000
#define NEOCMM_F_ENUM_TYPE_COLORSPACE	0x00200000
#define NEOCMM_F_ENUM_TYPE_NAMEDCOLOR	0x00400000


typedef int (* NEOCMM_ENUMPROFILE_CB) (neoCMMHPROFILE hProfile, const char* sFilename, void * pUserData);

// exported functions
#ifdef __cplusplus
extern "C" {
#endif

		/// Profile management and conversion funcions
		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_LoadStandardProfile(int iIndex, int defEngine /*= neoCMM_ENGINE_DEFAULT*/);
			
		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_LoadMonitorProfile(int defEngine /*= MOTOR_COLOR_DEF*/);
			
		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_LoadProfileFromFile(const char* pFileName, int defEngine /*= neoCMM_ENGINE_DEFAULT*/);

		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_LoadProfileFromBuffer(const  void * pData, unsigned long dwSzData, int defEngine /*= neoCMM_ENGINE_DEFAULT*/);

		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_LoadProfileFromName(const char* pName, unsigned long uFlags, int defEngine /*= neoCMM_ENGINE_DEFAULT*/);
		
		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_LoadProfileFromFileName(const char* pFileName, unsigned long uFlags, int defEngine /*= neoCMM_ENGINE_DEFAULT*/);
		
		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_RetainProfile(neoCMMHPROFILE profile);

		NEOCMM_API_DEC int neoCMM_GetProfileInformation(neoCMMHPROFILE profile, int tag, void* pData, unsigned long dwSzData);
	
		NEOCMM_API_DEC void neoCMM_CloseProfile(neoCMMHPROFILE *hProfile);

		/// Profile comparison (returns 0 if the profiles are identical, non 0 if they are different)
		NEOCMM_API_DEC int neoCMM_CompareProfiles(neoCMMHPROFILE profile1, neoCMMHPROFILE profile2);

		/// Color transform without profile
		NEOCMM_API_DEC neoCMMHTRANSFORM neoCMM_CreateDirectColorTrans(neoCMMHLRU pLRU /*=NULL*/);

		/// Color transform with profiles
		NEOCMM_API_DEC neoCMMHTRANSFORM neoCMM_CreateProfileColorTrans(const neoCMMHPROFILE profilesArray[], int intentsArray[], int nProfiles, unsigned long dwFlags, int defEngine /*= neoCMM_ENGINE_DEFAULT*/, neoCMMHLRU pLRU /*= NULL*/);

		NEOCMM_API_DEC int neoCMM_CompareTransforms(neoCMMHTRANSFORM hTrans1, neoCMMHTRANSFORM hTrans2);
	
		/// Conversion function
		NEOCMM_API_DEC int neoCMM_ConvertColors(neoCMMHTRANSFORM hTransform, const void * pSrc, neoCMM_typeFormatColor fmtSrc, void * pDst, neoCMM_typeFormatColor fmtDst, int nColors, void * pGamutWarningColor /*= NULL*/);

		// dispose color transform
		NEOCMM_API_DEC void neoCMM_CloseTransform(neoCMMHTRANSFORM * hTransform, neoCMMHLRU pLRU /*= NULL*/);

		// profiles folder
		NEOCMM_API_DEC int neoCMM_GetSystemProfilesFolder(char* pFolder, unsigned long dwSzData, short sDomain /*= 0*/);
				
		// monitor profile file
		NEOCMM_API_DEC int neoCMM_GetMonitorProfileFile(char* pFolder, unsigned long dwSzData, int defEngine /*= MOTOR_COLOR_DEF*/);
				
		// profile enumerator
		// enumeration
		NEOCMM_API_DEC void neoCMM_EnumerateProfiles(const char* pFolder, unsigned long uFlags, NEOCMM_ENUMPROFILE_CB pUserCB, void * pUserParams, int defEngine /*= neoCMM_ENGINE_DEFAULT*/);

		// engine availability
		NEOCMM_API_DEC int neoCMM_IsEngineAvailable(int iEngine);
	
		// working profiles
		NEOCMM_API_DEC int neoCMM_SetWorkingProfile(neoCMMHPROFILE profile, int space);
		NEOCMM_API_DEC neoCMMHPROFILE neoCMM_GetWorkingProfile(int space);
	
		// default color settings
		NEOCMM_API_DEC void neoCMM_DefaultColorSettings(neoCMMHPROFILE profileIn, neoCMMHPROFILE profileOut, int* iIntent, unsigned long* dwFlags);
	
		// create LRU (Last Recently Used) cache
		NEOCMM_API_DEC neoCMMHLRU neoCMM_CreateLRUTransformCache(int nItems);
	
		// closes a LRU transform cache
		NEOCMM_API_DEC void neoCMM_DeleteLRUTransformCache(neoCMMHLRU * pLRU);

	#ifdef __cplusplus
	} // extern "C"
	#endif



#endif	/*_NEO_CMM_H_*/
